// Pagination
//
// Pagination `/wyrm_addons/elements/_paginate.sass`.
//
// Markup:
// <ul class="wy-paginate {$modifiers}">
//   <li><a href="">&laquo;</a></li>
//   <li class="active"><a href="">3</a></li>
//   <li><a href="">4</a></li>
//   <li><a href="">5</a></li>
//   <li><a href="">6</a></li>
//   <li class="dots"><a href="">..</a></li>
//   <li><a href="">92</a></li>
//   <li><a href="">&raquo;</a></li>
// </ul>
//
// .wy-paginate-center        - Centered
//
// Styleguide 11.0

.wy-paginate
  margin-bottom: $base-line-height
  list-style: none
  li
    list-style: none
    display: inline-block
    margin: 0
  a
    display: inline-block
    padding: $base-line-height / 4 $base-line-height / 2
    border: solid 1px $table-border-color
    color: $text-color
    line-height: 1
    font-size: 90%
  a:hover
    background: $table-border-color
  li.active a
    background: $gray-dark
    border-color: $gray-dark
    color: $white !important
  li.dots a
    border-color: transparent
  &.wy-paginate-center
    text-align: center
