// ------------------------------------------------------------
// WYRM ALL
// ------------------------------------------------------------
// This file includes wym_core along with all its addons.
// ------------------------------------------------------------

@import wyrm_core

// Addons
@import wyrm_addons/forms/form_upload
@import wyrm_addons/forms/form_autocomplete
@import wyrm_addons/forms/form_tag
@import wyrm_addons/forms/form_gallery
@import wyrm_addons/pygments/pygments
@import wyrm_addons/pygments/pygments_light
@import wyrm_addons/elements/tooltip
@import wyrm_addons/elements/stars
@import wyrm_addons/elements/paginate
@import wyrm_addons/elements/modal
@import wyrm_addons/redactor/redactor
@import wyrm_addons/redactor/figures
