// Ratings
//
// Ratings using font icons. Located in `/wyrm_addons/elements/_stars.sass`.
//
// Markup:
// <span class="wy-star {$modifiers}"></span>
//
// .wy-star-0          - 0 stars
// .wy-star-0dot5      - 0.5 stars
// .wy-star-1          - 1 stars
// .wy-star-1dot5      - 1.5 stars
// .wy-star-2          - 2 stars
// .wy-star-2dot5      - 2.5 stars
// .wy-star-3          - 3 stars
// .wy-star-3dot5      - 3.5 stars
// .wy-star-4          - 4 stars
// .wy-star-4dot5      - 4.5 stars
// .wy-star-5          - 5 stars
//
// Styleguide 10.0

.wy-star
  display: inline-block
  max-width: 100%
  letter-spacing: 3px
  color: $text-light
  font-family: $icon-font-family
  vertical-align: top
  position: relative
  &:before
    content: "\f005\f005\f005\f005\f005"
  &:after
    position: absolute
    top: 0
    left: 0
    color: $text-color
  &.wy-star-0dot5:after
    content: "\f089"
  &.wy-star-1:after
    content: "\f005"
  &.wy-star-1dot5:after
    content: "\f005\f089"
  &.wy-star-2:after
    content: "\f005\f005"
  &.wy-star-2dot5:after
    content: "\f005\f005\f089"
  &.wy-star-3:after
    content: "\f005\f005\f005"
  &.wy-star-3dot5:after
    content: "\f005\f005\f005\f089"
  &.wy-star-4:after
    content: "\f005\f005\f005\f005"
  &.wy-star-4dot5:after
    content: "\f005\f005\f005\f005\f089"
  &.wy-star-5:after
    content: "\f005\f005\f005\f005\f005"
