// Gallery management

.wy-form-gallery-manage
  margin-left: -$base-line-height / 2
  margin-right: -$base-line-height / 2
  li
    float: left
    padding: $base-line-height / 2
    width: 20%
    cursor: pointer
    +media($tablet)
      width: 25%
    +media($mobile)
      width: 50%
    &:active
      cursor: move
  li > a
    padding: $base-line-height / 2
    background-color: #FFF
    border: solid 1px $table-border-color
    border-bottom: solid 3px $table-border-color
    display: inline-block
    +transition(all .1s ease-in)
    &:active
      border: solid 1px $input-border-color
      border-top: solid 3px $input-border-color
  img
    width: 100%
    +transition(all .05s ease-in)

li.wy-form-gallery-edit
  position: relative
  color: $text-invert
  padding: $base-line-height
  width: 100%
  display: block
  background-color: $menu-background-color
  border-radius: 4px
  .arrow
    position: absolute
    display: block
    top: -50px
    left: 50%
    margin-left: -25px
    z-index: 500
    +triangle(50px, $menu-background-color, up)

