.wy-form-upload-container
  vertical-align: middle

.wy-form-upload
  display: inline-block
  cursor: pointer
  color: $text-color
  vertical-align: middle
  +transition(border-color .1s ease-in)
  +clearfix
  +media($mobile)
    width: 100%
  .image-drop
    display: none
  .image-desktop
    display: none
  .image-loading
    display: none
  .image-drop .wy-form-upload-icon
    color: $green
  p
    font-size: 90%
    margin-bottom: $base-line-height / 4
  .wy-form-upload-image
    display: inline-block
    line-height: 150px
    text-align: center
    margin-right: $base-line-height / 2
    vertical-align: middle
    .icon
      font-size: 50px
      line-height: 75px
  img
    max-width: 150px
    max-height: 150px
  .wy-form-upload-content
    vertical-align: middle
    display: inline-block
    +media($mobile)
      width: 100%

.wy-form-upload.wy-form-upload-big
  width: 100%
  text-align: center
  padding: $base-line-height * 3
  .wy-form-upload-content
    float: none

.wy-form-upload-url
  padding: 18px 0px
  vertical-align: middle

.wy-form-upload.wy-form-upload-file
  p
    margin-bottom: 0
  .wy-form-upload-icon
    display: inline-block
    font-size: inherit

.wy-form-upload.wy-form-upload-drop
  background-color: lighten($green, 50%)
  .image-drop
    display: block
  .image-desktop
    display: none
  .image-drag
    display: none

.wy-form-upload.wy-form-upload-loading
  .image-drag
    display: none
  .image-desktop
    display: none
  .image-loading
    display: block
  .wy-input-prefix
    display: none
  p
    margin-bottom: 0

+media($mobile)
  .wy-form-upload
    .wy-form-upload-image
      margin-bottom: $base-line-height / 2

